@@ -10,7 +10,7 @@ import matplotlib.pyplot as pyplot
 
 
 
-def generate_demographic_contact_network(N, demographic_data, layer_generator='FARZ', layer_info=None, distancing_scales=[], isolation_groups=[]):
+def generate_demographic_contact_network(N, demographic_data, layer_generator='FARZ', layer_info=None, distancing_scales=[], isolation_groups=[], verbose=False):
 
     graphs = {}
 
@@ -22,7 +22,7 @@ def generate_demographic_contact_network(N, demographic_data, layer_generator='F
     # Preprocess Demographic Statistics:
     #########################################
     meanHouseholdSize = numpy.average(list(household_size_distn.keys()), weights=list(household_size_distn.values()))
-    print("mean household size: " + str(meanHouseholdSize))
+    # print("mean household size: " + str(meanHouseholdSize))
 
     # Calculate the distribution of household sizes given that the household has more than 1 member:
     household_size_distn_givenGT1 = {key: value/(1-household_size_distn[1]) for key, value in household_size_distn.items()}
@@ -211,8 +211,6 @@ def generate_demographic_contact_network(N, demographic_data, layer_generator='F
 
             homelessNodes -= household['size']
 
-            # household['indices'] = range(curMemberIndex, curMemberIndex+household['size'])
-
             households.append(household)
 
         else:
@@ -220,7 +218,7 @@ def generate_demographic_contact_network(N, demographic_data, layer_generator='F
 
 
     numHouseholds = len(households)
-    print("Num households: " +str(numHouseholds))
+
 
 
     #~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
@@ -230,36 +228,41 @@ def generate_demographic_contact_network(N, demographic_data, layer_generator='F
     for ageBracket in sorted(age_distn):
         age_freq = numpy.sum([len([age for age in household['ageBrackets'] if age==ageBracket]) for household in households])/N
         print(str(ageBracket)+": %.4f\t(%.4f from target)" % (age_freq, (age_freq - age_distn[ageBracket])) )
+    print()
 
     print("Generated household size distribution:")
     for size in sorted(household_size_distn):
         size_freq = numpy.sum([1 for household in households if household['size']==size])/numHouseholds
         print(str(size)+": %.4f\t(%.4f from target)" % (size_freq, (size_freq - household_size_distn[size])) )
+    print("Num households: " +str(numHouseholds))
+    print("mean household size: " + str(meanHouseholdSize))
+    print()
     
-    print("Generated percent households with at least one member Under 20:")
-    checkval = len([household for household in households if not set(household['ageBrackets']).isdisjoint(ageBrackets_U20)])/numHouseholds
-    target   = pctHouseholdsWithMember_U20
-    print("%.4f\t\t(%.4f from target)" % (checkval, checkval - target))
-    
-    print("Generated percent households with at least one Over 60")
-    checkval = len([household for household in households if not set(household['ageBrackets']).isdisjoint(ageBrackets_O60)])/numHouseholds
-    target   = pctHouseholdsWithMember_O60
-    print("%.4f\t\t(%.4f from target)" % (checkval, checkval - target))
-    
-    print("Generated percent households with at least one Under 20 AND Over 60")
-    checkval = len([household for household in households if not set(household['ageBrackets']).isdisjoint(ageBrackets_O60) and not set(household['ageBrackets']).isdisjoint(ageBrackets_U20)])/numHouseholds
-    target   = pctHouseholdsWithMember_U20andO60
-    print("%.4f\t\t(%.4f from target)" % (checkval, checkval - target))
-    
-    print("Generated percent households with 1 total member who is Over 60")
-    checkval = numpy.sum([1 for household in households if household['size']==1 and not set(household['ageBrackets']).isdisjoint(ageBrackets_O60)])/numHouseholds
-    target   = pctHouseholdsWithMember_O60_givenEq1*prob_eq1
-    print("%.4f\t\t(%.4f from target)" % (checkval, checkval - target))
+    if(verbose):
+        print("Generated percent households with at least one member Under 20:")
+        checkval = len([household for household in households if not set(household['ageBrackets']).isdisjoint(ageBrackets_U20)])/numHouseholds
+        target   = pctHouseholdsWithMember_U20
+        print("%.4f\t\t(%.4f from target)" % (checkval, checkval - target))
+        
+        print("Generated percent households with at least one Over 60")
+        checkval = len([household for household in households if not set(household['ageBrackets']).isdisjoint(ageBrackets_O60)])/numHouseholds
+        target   = pctHouseholdsWithMember_O60
+        print("%.4f\t\t(%.4f from target)" % (checkval, checkval - target))
+        
+        print("Generated percent households with at least one Under 20 AND Over 60")
+        checkval = len([household for household in households if not set(household['ageBrackets']).isdisjoint(ageBrackets_O60) and not set(household['ageBrackets']).isdisjoint(ageBrackets_U20)])/numHouseholds
+        target   = pctHouseholdsWithMember_U20andO60
+        print("%.4f\t\t(%.4f from target)" % (checkval, checkval - target))
+        
+        print("Generated percent households with 1 total member who is Over 60")
+        checkval = numpy.sum([1 for household in households if household['size']==1 and not set(household['ageBrackets']).isdisjoint(ageBrackets_O60)])/numHouseholds
+        target   = pctHouseholdsWithMember_O60_givenEq1*prob_eq1
+        print("%.4f\t\t(%.4f from target)" % (checkval, checkval - target))
 
-    print("Generated mean num members Under 20 given at least one member is Under 20")
-    checkval = numpy.mean([numpy.in1d(household['ageBrackets'], ageBrackets_U20).sum() for household in households if not set(household['ageBrackets']).isdisjoint(ageBrackets_U20)])
-    target   = meanNumU20PerHousehold_givenU20
-    print("%.4f\t\t(%.4f from target)" % (checkval, checkval - target))
+        print("Generated mean num members Under 20 given at least one member is Under 20")
+        checkval = numpy.mean([numpy.in1d(household['ageBrackets'], ageBrackets_U20).sum() for household in households if not set(household['ageBrackets']).isdisjoint(ageBrackets_U20)])
+        target   = meanNumU20PerHousehold_givenU20
+        print("%.4f\t\t(%.4f from target)" % (checkval, checkval - target))
 
     #
 
@@ -362,8 +365,9 @@ def generate_demographic_contact_network(N, demographic_data, layer_generator='F
                 if(meanDegree+meanHouseholdSize >= targetMeanDegreeRange[0] and meanDegree+meanHouseholdSize <= targetMeanDegreeRange[1]):
                 # if(meanDegree+meanHouseholdSize >= targetMeanDegree+meanHouseholdSize-1 and meanDegree+meanHouseholdSize <= targetMeanDegree+meanHouseholdSize+1):
             
-                    print(layerGroup+" public mean degree = "+str((meanDegree)))
-                    print(layerGroup+" public max degree  = "+str((maxDegree)))
+                    if(verbose):
+                        print(layerGroup+" public mean degree = "+str((meanDegree)))
+                        print(layerGroup+" public max degree  = "+str((maxDegree)))
 
                     adjMatrices.append(networkx.adj_matrix(layerInfo['graph']))
 
@@ -389,8 +393,9 @@ def generate_demographic_contact_network(N, demographic_data, layer_generator='F
                         elif(meanDegree+meanHouseholdSize > targetMeanDegreeRange[1]):
                             targetMeanDegree -= 1 if layer_generator=='FARZ' else 0.05
                         # reload(networkx)
-                    # print("Try again... (mean degree = "+str(meanDegree)+"+"+str(meanHouseholdSize)+" is outside the target range for mean degree "+str(targetMeanDegreeRange)+")")
-                    print("\tTry again... (mean degree = %.2f+%.2f=%.2f is outside the target range for mean degree (%.2f, %.2f)" % (meanDegree, meanHouseholdSize, meanDegree+meanHouseholdSize, targetMeanDegreeRange[0], targetMeanDegreeRange[1]))
+                    if(verbose):
+                        # print("Try again... (mean degree = "+str(meanDegree)+"+"+str(meanHouseholdSize)+" is outside the target range for mean degree "+str(targetMeanDegreeRange)+")")
+                        print("\tTry again... (mean degree = %.2f+%.2f=%.2f is outside the target range for mean degree (%.2f, %.2f)" % (meanDegree, meanHouseholdSize, meanDegree+meanHouseholdSize, targetMeanDegreeRange[0], targetMeanDegreeRange[1]))
             
             # The networks LFR graph generator function has unreliable convergence.
             # If it fails to converge in allotted iterations, try again to generate.
@@ -399,7 +404,8 @@ def generate_demographic_contact_network(N, demographic_data, layer_generator='F
                 graph_gen_attempts += 1
                 # if(graph_gen_attempts >= 10 and graph_gen_attempts % 10):
                 #     reload(networkx)
-                print("\tTry again... (networkx failed to converge on a graph)")
+                if(verbose):
+                    print("\tTry again... (networkx failed to converge on a graph)")
 
     #~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
     # Assemble an graph for the full population out of the adjacencies generated for each layer:
@@ -409,33 +415,6 @@ def generate_demographic_contact_network(N, demographic_data, layer_generator='F
     G_baseline = networkx.from_scipy_sparse_matrix(A_baseline)
     graphs['baseline'] = G_baseline
 
-    #~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
-    # Check the connectivity of the baseline public contacts graph that of each age group's graph layer:
-    #~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
-    # nodeDegrees_baseline_public    = [d[1] for d in G_baseline.degree()]
-    # meanDegree_baseline_public= numpy.mean(nodeDegrees_baseline_public)
-    # maxDegree_baseline_public= numpy.max(nodeDegrees_baseline_public)
-    # components = sorted(networkx.connected_components(G_baseline), key=len, reverse=True)
-    # numConnectedComps = len(components)
-    # largestConnectedComp = G_baseline.subgraph(components[0])
-    # print("G_baseline mean degree = "+str((meanDegree_baseline_public)))
-    # print("G_baseline max degree = "+str((maxDegree_baseline_public)))
-    # print("G_baseline number of connected components = {0:d}".format(numConnectedComps))
-    # print("G_baseline largest connected component = {0:d}".format(len(largestConnectedComp)))
-    # for layerGroup, layerInfo in layer_info.items():
-    #     nodeDegrees_group = A_baseline[min(layerInfo['indices']):max(layerInfo['indices']), :].sum(axis=1)
-    #     print(layerGroup+" public graph mean degree = "+str(numpy.mean(nodeDegrees_group)))
-    #     print(layerGroup+" public graph max degree  = "+str(numpy.max(nodeDegrees_group)))
-    #     pyplot.hist(nodeDegrees_group, bins=range(int(max(nodeDegrees_group))), alpha=0.5, label=layerGroup)
-    # # pyplot.hist(nodeDegrees_baseline_public, bins=range(int(max(nodeDegrees_baseline_public))), alpha=0.5, color='tab:red', label='Full Pop')
-    # pyplot.xlim(0,40)
-    # pyplot.xlabel('degree')
-    # pyplot.ylabel('num nodes')
-    # pyplot.legend(loc='upper right')
-    # pyplot.show()
-
-    
-
 
     #########################################
     # Generate social distancing modifications to the baseline *public* contact network:
@@ -452,40 +431,18 @@ def generate_demographic_contact_network(N, demographic_data, layer_generator='F
     for dist_scale in distancing_scales:
         graphs['distancingScale'+str(dist_scale)] = custom_exponential_graph(G_baseline_NODIST, scale=dist_scale)
 
-        # Check the connectivity of the social distancing public contact graphs (which include connections for all age groups):
-        # nodeDegrees_baseline_public_NODIST    = [d[1] for d in G_baseline_NODIST.degree()]
-        # meanDegree_baseline_public_NODIST= numpy.mean(nodeDegrees_baseline_public_NODIST)
-        # maxDegree_baseline_public_NODIST= numpy.max(nodeDegrees_baseline_public_NODIST)
-        # components = sorted(networkx.connected_components(G_baseline_NODIST), key=len, reverse=True)
-        # numConnectedComps = len(components)
-        # largestConnectedComp = G_baseline_NODIST.subgraph(components[0])
-        # print("G_baseline_NODIST mean degree = "+str((meanDegree_baseline_public_NODIST)))
-        # print("G_baseline_NODIST max degree = "+str((maxDegree_baseline_public_NODIST)))
-        # print("G_baseline_NODIST number of connected components = {0:d}".format(numConnectedComps))
-        # print("G_baseline_NODIST largest connected component = {0:d}".format(len(largestConnectedComp)))
-
-        nodeDegrees_baseline_public_DIST    = [d[1] for d in graphs['distancingScale'+str(dist_scale)].degree()]
-        print("Distancing Public Degree Pcts:")
-        (unique, counts) = numpy.unique(nodeDegrees_baseline_public_DIST, return_counts=True)
-        print([str(unique)+": "+str(count/N) for (unique, count) in zip(unique, counts)])
-        # meanDegree_baseline_public_DIST= numpy.mean(nodeDegrees_baseline_public_DIST)
-        # maxDegree_baseline_public_DIST= numpy.max(nodeDegrees_baseline_public_DIST)
-        # components = sorted(networkx.connected_components(graphs['distancingScale'+str(dist_scale)]), key=len, reverse=True)
-        # numConnectedComps = len(components)
-        # largestConnectedComp = graphs['distancingScale'+str(dist_scale)].subgraph(components[0])
-        # print("G_distancing scale"+str(dist_scale)+" mean degree = "+str((meanDegree_baseline_public_DIST)))
-        # print("G_distancing scale"+str(dist_scale)+" max degree = "+str((maxDegree_baseline_public_DIST)))
-        # print("G_distancing scale"+str(dist_scale)+" number of connected components = {0:d}".format(numConnectedComps))
-        # print("G_distancing scale"+str(dist_scale)+" largest connected component = {0:d}".format(len(largestConnectedComp)))
-
-        # pyplot.hist(nodeDegrees_baseline_public_NODIST, bins=range(int(max(nodeDegrees_baseline_public_NODIST))), alpha=0.5, color='tab:blue', label='Public Contacts (no dist)')
-        pyplot.hist(nodeDegrees_baseline_public_DIST, bins=range(int(max(nodeDegrees_baseline_public_DIST))), alpha=0.5, color='tab:purple', label='Public Contacts (distancingScale'+str(dist_scale)+')')
-    
-        pyplot.xlim(0,40)
-        pyplot.xlabel('degree')
-        pyplot.ylabel('num nodes')
-        pyplot.legend(loc='upper right')
-        pyplot.show()
+        if(verbose):
+            nodeDegrees_baseline_public_DIST    = [d[1] for d in graphs['distancingScale'+str(dist_scale)].degree()]
+            print("Distancing Public Degree Pcts:")
+            (unique, counts) = numpy.unique(nodeDegrees_baseline_public_DIST, return_counts=True)
+            print([str(unique)+": "+str(count/N) for (unique, count) in zip(unique, counts)])
+            # pyplot.hist(nodeDegrees_baseline_public_NODIST, bins=range(int(max(nodeDegrees_baseline_public_NODIST))), alpha=0.5, color='tab:blue', label='Public Contacts (no dist)')
+            pyplot.hist(nodeDegrees_baseline_public_DIST, bins=range(int(max(nodeDegrees_baseline_public_DIST))), alpha=0.5, color='tab:purple', label='Public Contacts (distancingScale'+str(dist_scale)+')')
+            pyplot.xlim(0,40)
+            pyplot.xlabel('degree')
+            pyplot.ylabel('num nodes')
+            pyplot.legend(loc='upper right')
+            pyplot.show()
 
 
     #########################################
@@ -546,28 +503,29 @@ def generate_demographic_contact_network(N, demographic_data, layer_generator='F
     #########################################
     # Check the connectivity of the fully constructed contacts graphs for each age group's layer:
     #########################################
-    for graphName, graph in graphs.items():
-        nodeDegrees    = [d[1] for d in graph.degree()]
-        meanDegree= numpy.mean(nodeDegrees)
-        maxDegree= numpy.max(nodeDegrees)
-        components = sorted(networkx.connected_components(graph), key=len, reverse=True)
-        numConnectedComps = len(components)
-        largestConnectedComp = graph.subgraph(components[0])
-        print(graphName+": Overall mean degree = "+str((meanDegree)))
-        print(graphName+": Overall max degree = "+str((maxDegree)))
-        print(graphName+": number of connected components = {0:d}".format(numConnectedComps))
-        print(graphName+": largest connected component = {0:d}".format(len(largestConnectedComp)))
-        for layerGroup, layerInfo in layer_info.items():
-            nodeDegrees_group = networkx.adj_matrix(graph)[min(layerInfo['indices']):max(layerInfo['indices']), :].sum(axis=1)
-            print("\t"+graphName+": "+layerGroup+" final graph mean degree = "+str(numpy.mean(nodeDegrees_group)))
-            print("\t"+graphName+": "+layerGroup+" final graph max degree  = "+str(numpy.max(nodeDegrees_group)))
-            pyplot.hist(nodeDegrees_group, bins=range(int(max(nodeDegrees_group))), alpha=0.5, label=layerGroup)
-        # pyplot.hist(nodeDegrees, bins=range(int(max(nodeDegrees))), alpha=0.5, color='black', label=graphName)
-        pyplot.xlim(0,40)
-        pyplot.xlabel('degree')
-        pyplot.ylabel('num nodes')
-        pyplot.legend(loc='upper right')
-        pyplot.show()
+    if(verbose):
+        for graphName, graph in graphs.items():
+            nodeDegrees    = [d[1] for d in graph.degree()]
+            meanDegree= numpy.mean(nodeDegrees)
+            maxDegree= numpy.max(nodeDegrees)
+            components = sorted(networkx.connected_components(graph), key=len, reverse=True)
+            numConnectedComps = len(components)
+            largestConnectedComp = graph.subgraph(components[0])
+            print(graphName+": Overall mean degree = "+str((meanDegree)))
+            print(graphName+": Overall max degree = "+str((maxDegree)))
+            print(graphName+": number of connected components = {0:d}".format(numConnectedComps))
+            print(graphName+": largest connected component = {0:d}".format(len(largestConnectedComp)))
+            for layerGroup, layerInfo in layer_info.items():
+                nodeDegrees_group = networkx.adj_matrix(graph)[min(layerInfo['indices']):max(layerInfo['indices']), :].sum(axis=1)
+                print("\t"+graphName+": "+layerGroup+" final graph mean degree = "+str(numpy.mean(nodeDegrees_group)))
+                print("\t"+graphName+": "+layerGroup+" final graph max degree  = "+str(numpy.max(nodeDegrees_group)))
+                pyplot.hist(nodeDegrees_group, bins=range(int(max(nodeDegrees_group))), alpha=0.5, label=layerGroup)
+            # pyplot.hist(nodeDegrees, bins=range(int(max(nodeDegrees))), alpha=0.5, color='black', label=graphName)
+            pyplot.xlim(0,40)
+            pyplot.xlabel('degree')
+            pyplot.ylabel('num nodes')
+            pyplot.legend(loc='upper right')
+            pyplot.show()
 
     #########################################
 
